==> haskell-ghc-lib-parser-8.10.5.20210606-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-lib-parser
version:              8.10.5.20210606
visibility:           public
id:                   ghc-lib-parser-8.10.5.20210606-Cd7ZmKI18GmFZVpU2ZyZVZ
key:                  ghc-lib-parser-8.10.5.20210606-Cd7ZmKI18GmFZVpU2ZyZVZ
license:              BSD-3-Clause
maintainer:           Digital Asset
author:               The GHC Team and Digital Asset
homepage:             https://github.com/digital-asset/ghc-lib
synopsis:             The GHC API, decoupled from GHC versions
description:
    A package equivalent to the @ghc@ package, but which can be loaded on many compiler versions.

category:             Development
abi:                  d028213b53a2a51ffcc3df5615056c99
exposed-modules:
    Annotations ApiAnnotation Avail Bag BasicTypes BinFingerprint
    Binary BkpSyn BooleanFormula BufWrite ByteCodeTypes Class CliOption
    CmdLineParser CmmType CoAxiom Coercion ConLike Config Constants
    Constraint CoreArity CoreFVs CoreMap CoreMonad CoreOpt CoreSeq
    CoreStats CoreSubst CoreSyn CoreTidy CoreUnfold CoreUtils
    CostCentre CostCentreState Ctype DataCon Demand Digraph
    DriverPhases DynFlags Encoding EnumSet ErrUtils Exception FV
    FamInstEnv FastFunctions FastMutInt FastString FastStringEnv
    FieldLabel FileCleanup FileSettings Fingerprint FiniteMap
    ForeignCall GHC.BaseDir GHC.Exts.Heap GHC.Exts.Heap.ClosureTypes
    GHC.Exts.Heap.Closures GHC.Exts.Heap.Constants
    GHC.Exts.Heap.InfoTable GHC.Exts.Heap.InfoTable.Types
    GHC.Exts.Heap.InfoTableProf GHC.Exts.Heap.Utils GHC.ForeignSrcLang
    GHC.ForeignSrcLang.Type GHC.Hs GHC.Hs.Binds GHC.Hs.Decls GHC.Hs.Doc
    GHC.Hs.Dump GHC.Hs.Expr GHC.Hs.Extension GHC.Hs.ImpExp
    GHC.Hs.Instances GHC.Hs.Lit GHC.Hs.Pat GHC.Hs.PlaceHolder
    GHC.Hs.Types GHC.Hs.Utils GHC.HsToCore.PmCheck.Types
    GHC.LanguageExtensions GHC.LanguageExtensions.Type GHC.Lexeme
    GHC.PackageDb GHC.Platform GHC.Serialized GHC.UniqueSubdir
    GHC.Version GHCi.BreakArray GHCi.FFI GHCi.Message GHCi.RemoteTypes
    GHCi.TH.Binary GhcMonad GhcNameVersion GhcPrelude HaddockUtils
    HeaderInfo Hooks HscTypes IOEnv Id IdInfo IfaceSyn IfaceType
    InstEnv InteractiveEvalTypes Json KnownUniques Language.Haskell.TH
    Language.Haskell.TH.LanguageExtensions Language.Haskell.TH.Lib
    Language.Haskell.TH.Lib.Internal Language.Haskell.TH.Lib.Map
    Language.Haskell.TH.Ppr Language.Haskell.TH.PprLib
    Language.Haskell.TH.Syntax Lexeme Lexer LinkerTypes ListSetOps
    Literal Maybes MkCore MkId Module MonadUtils Name NameCache NameEnv
    NameSet OccName OccurAnal OptCoercion OrdList Outputable
    PackageConfig Packages Pair Panic Parser PatSyn PipelineMonad
    PlainPanic PlatformConstants Plugins PprColour PprCore Predicate
    PrelNames PrelRules Pretty PrimOp RdrHsSyn RdrName RepType Rules
    Settings SizedSeq SrcLoc StringBuffer SysTools.BaseDir
    SysTools.Terminal TcEvidence TcHoleFitTypes TcOrigin TcRnTypes
    TcType ToIface ToolSettings TrieMap TyCoFVs TyCoPpr TyCoRep
    TyCoSubst TyCoTidy TyCon Type TysPrim TysWiredIn Unify UniqDFM
    UniqDSet UniqFM UniqSet UniqSupply Unique Util Var VarEnv VarSet

import-dirs:
    /usr/lib/ghc-9.0.1/site-local/ghc-lib-parser-8.10.5.20210606

library-dirs:
    /usr/lib/ghc-9.0.1/site-local/ghc-lib-parser-8.10.5.20210606

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/ghc-lib-parser-8.10.5.20210606

hs-libraries:         HSghc-lib-parser-8.10.5.20210606-Cd7ZmKI18GmFZVpU2ZyZVZ
depends:
    array-0.5.4.0 base-4.15.0.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 deepseq-1.4.5.0 directory-1.3.6.1
    filepath-1.4.2.1 ghc-prim-0.7.0 hpc-0.6.1.0 pretty-1.1.3.6
    process-1.6.11.0 time-1.9.3 transformers-0.5.6.2 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser/html/ghc-lib-parser.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-lib-parser-8.10.5.20210606-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-lib-parser
version:              8.10.5.20210606
visibility:           public
id:                   ghc-lib-parser-8.10.5.20210606-7jpwkYARfluCRNplNhV1BZ
key:                  ghc-lib-parser-8.10.5.20210606-7jpwkYARfluCRNplNhV1BZ
license:              BSD-3-Clause
maintainer:           Digital Asset
author:               The GHC Team and Digital Asset
homepage:             https://github.com/digital-asset/ghc-lib
synopsis:             The GHC API, decoupled from GHC versions
description:
    A package equivalent to the @ghc@ package, but which can be loaded on many compiler versions.

category:             Development
abi:                  09636c6597344012880fba1eae1d3a44
exposed-modules:
    Annotations ApiAnnotation Avail Bag BasicTypes BinFingerprint
    Binary BkpSyn BooleanFormula BufWrite ByteCodeTypes Class CliOption
    CmdLineParser CmmType CoAxiom Coercion ConLike Config Constants
    Constraint CoreArity CoreFVs CoreMap CoreMonad CoreOpt CoreSeq
    CoreStats CoreSubst CoreSyn CoreTidy CoreUnfold CoreUtils
    CostCentre CostCentreState Ctype DataCon Demand Digraph
    DriverPhases DynFlags Encoding EnumSet ErrUtils Exception FV
    FamInstEnv FastFunctions FastMutInt FastString FastStringEnv
    FieldLabel FileCleanup FileSettings Fingerprint FiniteMap
    ForeignCall GHC.BaseDir GHC.Exts.Heap GHC.Exts.Heap.ClosureTypes
    GHC.Exts.Heap.Closures GHC.Exts.Heap.Constants
    GHC.Exts.Heap.InfoTable GHC.Exts.Heap.InfoTable.Types
    GHC.Exts.Heap.InfoTableProf GHC.Exts.Heap.Utils GHC.ForeignSrcLang
    GHC.ForeignSrcLang.Type GHC.Hs GHC.Hs.Binds GHC.Hs.Decls GHC.Hs.Doc
    GHC.Hs.Dump GHC.Hs.Expr GHC.Hs.Extension GHC.Hs.ImpExp
    GHC.Hs.Instances GHC.Hs.Lit GHC.Hs.Pat GHC.Hs.PlaceHolder
    GHC.Hs.Types GHC.Hs.Utils GHC.HsToCore.PmCheck.Types
    GHC.LanguageExtensions GHC.LanguageExtensions.Type GHC.Lexeme
    GHC.PackageDb GHC.Platform GHC.Serialized GHC.UniqueSubdir
    GHC.Version GHCi.BreakArray GHCi.FFI GHCi.Message GHCi.RemoteTypes
    GHCi.TH.Binary GhcMonad GhcNameVersion GhcPrelude HaddockUtils
    HeaderInfo Hooks HscTypes IOEnv Id IdInfo IfaceSyn IfaceType
    InstEnv InteractiveEvalTypes Json KnownUniques Language.Haskell.TH
    Language.Haskell.TH.LanguageExtensions Language.Haskell.TH.Lib
    Language.Haskell.TH.Lib.Internal Language.Haskell.TH.Lib.Map
    Language.Haskell.TH.Ppr Language.Haskell.TH.PprLib
    Language.Haskell.TH.Syntax Lexeme Lexer LinkerTypes ListSetOps
    Literal Maybes MkCore MkId Module MonadUtils Name NameCache NameEnv
    NameSet OccName OccurAnal OptCoercion OrdList Outputable
    PackageConfig Packages Pair Panic Parser PatSyn PipelineMonad
    PlainPanic PlatformConstants Plugins PprColour PprCore Predicate
    PrelNames PrelRules Pretty PrimOp RdrHsSyn RdrName RepType Rules
    Settings SizedSeq SrcLoc StringBuffer SysTools.BaseDir
    SysTools.Terminal TcEvidence TcHoleFitTypes TcOrigin TcRnTypes
    TcType ToIface ToolSettings TrieMap TyCoFVs TyCoPpr TyCoRep
    TyCoSubst TyCoTidy TyCon Type TysPrim TysWiredIn Unify UniqDFM
    UniqDSet UniqFM UniqSet UniqSupply Unique Util Var VarEnv VarSet

import-dirs:
    /usr/lib/ghc-9.0.2/site-local/ghc-lib-parser-8.10.5.20210606

library-dirs:
    /usr/lib/ghc-9.0.2/site-local/ghc-lib-parser-8.10.5.20210606

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/ghc-lib-parser-8.10.5.20210606

hs-libraries:         HSghc-lib-parser-8.10.5.20210606-7jpwkYARfluCRNplNhV1BZ
depends:
    array-0.5.4.0 base-4.15.1.0 binary-0.8.8.0 bytestring-0.10.12.1
    containers-0.6.4.1 deepseq-1.4.5.0 directory-1.3.6.2
    filepath-1.4.2.1 ghc-prim-0.7.0 hpc-0.6.1.0 pretty-1.1.3.6
    process-1.6.13.2 time-1.9.3 transformers-0.5.6.2 unix-2.7.2.2

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser/html/ghc-lib-parser.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
